<template>
  <div class="content mask-div" v-loading="reqLoading" element-loading-text="加载中..."
    element-loading-spinner="el-icon-loading" element-loading-background="rgba(255, 255, 255, 1)">
    <div class="table-box">
      <div ref="pdfBox">
        <table border="1" width="100%" min-height="300" bordercolor="#333" cellspacing="0" align="center">
          <tr>
            <th colspan="36" class="table-tile">
              <p>{{ dateData.year }}年度市级重大改革项目推进情况基础表</p>
              （报表生成时间：{{ newDate }}）
            </th>
          </tr>
          <!-- 项目基本信息 -->
          <tr class="table-ceven">
            <th colspan="6" style="border-right: 1px solid;">项目名称</th>
            <td colspan="6" style="border-left: none;">{{ projectInfo.projectName }}</td>
            <th colspan="6">项目类型</th>
            <td colspan="6">
              {{ getDictName('xmlx', projectInfo.projectType) }}
            </td>
            <th colspan="6">所属领域</th>
            <td colspan="6">
              {{ getDictName('ggbb_ssly', projectInfo.projectField) }}
            </td>

          </tr>
          <tr class="table-ceven table-reven">
            <th colspan="6" style="border-right: 1px solid;">所属跑道</th>
            <td colspan="6" style="border-left: none;">
              {{ getDictName('ggbb_sspd', projectInfo.projectRunway) }}
            </td>
            <th colspan="6">牵头市领导</th>
            <td colspan="6">{{ projectInfo.leader }}</td>
            <th colspan="6">责任单位</th>
            <td colspan="6">{{ projectInfo.unitName }}</td>
          </tr>
          <!-- 量化目标 -->
          <tr class="table-ceven" v-if="goalList.length">
            <th class="propel-title" style="border-bottom: 1px solid;font-size: '20PX';" colspan="3"
              :rowspan="goalList.length + 1">
              改<br />革<br />方<br />案<br />量<br />化<br />目<br />标<br />
              完<br />成<br />情<br />况
            </th>
            <th colspan="3">年度目标值</th>
            <th colspan="3">月度目标值</th>
            <th colspan="3">当前值</th>
            <th colspan="24">指标内容</th>
          <tr class="table-c-even" v-for="goal in goalList" :key="goal.id">
            <td colspan="3">{{ goal.yearValue }} （{{ goal.unit }}）</td>
            <td colspan="3">{{ goal.monthValue }}（{{ goal.unit }}）</td>
            <td colspan="3">{{ goal.value }}（{{ goal.unit }}）</td>
            <td colspan="24">{{ goal.content }}</td>
          </tr>
          </tr>
          <!-- 月度计划 -->
          <tr class="table-ceven" v-if="monthList.length">
            <th colspan="3" style="border-bottom: 1px solid;" :rowspan="monthList.length + 1">
              改<br />革<br />方<br />案<br />月<br />度<br />计<br />划<br />
              完<br />成<br />情<br />况
            </th>
            <th colspan="3">计划月度</th>
            <th colspan="3">计划类型</th>
            <th colspan="3">推进状态</th>
            <th colspan="7">计划内容</th>
            <th colspan="11">已完成工作</th>
            <th colspan="6">下一步工作计划</th>
          <tr class="table-c-even" v-for="month in monthList" :key="month.id">
            <td colspan="3">
              {{
                month.planMonth < 13 ? `${month.planYear}年${month.planMonth}月` : '持续实施' }} </td>
            <td colspan="3">
              {{ getDictName('yd_jhlx', month.planType) }}
            </td>
            <td colspan="3">{{ getDictName('tjzt', month.isOver) }}</td>
            <td colspan="7" class="text-box">{{ month.planContent }}</td>
            <td colspan="11" class="text-box">{{ month.completedWork }}</td>
            <td colspan="6" class="text-box">{{ month.workPlan }}</td>
          </tr>
          </tr>
          <!-- 经验复制推广 -->
          <tr class="table-ceven" v-if="expList.length">
            <th style="border-bottom: 0;" colspan="3" :rowspan="expList && (expList.length + 1)">
              改<br />革<br />方<br />案<br />经<br />验<br />复<br />制<br />推<br />广<br />
              完<br />成<br />情<br />况
            </th>
            <th colspan="3">推广方式</th>
            <th colspan="3">推广日期</th>
            <th colspan="27">具体情况</th>
          <tr class="table-c-even" v-for="exp in expList" :key="exp.id">
            <td colspan="3">
              {{ getDictName('tgxs', exp.promotionType) }}
            </td>
            <td colspan="3">
              {{ exp.promotionDate }}
            </td>
            <td colspan="27">{{ exp.promotionContent }}</td>
          </tr>
          </tr>
        </table>
      </div>
      <!-- <el-button :loading="exportLoading" class="export-project" @click="exportPdf" type="primary">导出pdf</el-button> -->

    </div>
  </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView'
import utils from '@/utils.js'
import html2canvas from 'html2canvas'
import jsPDF from 'jspdf'
import moment from 'moment'
export default {
  name: 'projectDetail',
  data() {
    return {
      reqLoading: false,
      exportLoading: false,
      dateData: {
        year: '',
        month: ''
      },
      // 当前时间
      newDate: '',
      projectInfo: {},
      // 量化目标
      goalList: [],
      // 月度计划
      monthList: [],
      // 品牌显示度
      brandList: [],
      // 经验复制推广
      expList: [],
      // 举措迭代
      iterationList: []
    }
  },
  mounted() {
    this.newDate = moment(new Date()).format('YYYY年MM月DD日 HH:mm:ss')
    let reqData = JSON.parse(sessionStorage.getItem('searchDate'))
    reqData.projectId = this.$route.query.projectId
    this.dateData = reqData
    this.getData(reqData)
  },
  methods: {
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    getData(data) {
      this.reqLoading = true
      apiList.getProjectDetailById(data, res => {
        // 项目基础信息
        this.projectInfo = res.municipalMajorProjectManagement
        // 量化目标
        this.goalList = res.pilotQuantitativeObjectivesList || []
        // 月度计划
        this.monthList = res.pilotMeasuresPushList || []
        // 品牌显示度
        this.brandList = res.pilotBrandPushList || []
        // 经验复制推广
        this.expList = res.pilotExperiencePushList || []
        // 举措迭代
        this.iterationList = res.pilotSpecificMeasuresHistoryList || []
        this.reqLoading = false
      })
    },
    async exportPdf() {
      this.$nextTick(() => {
        let pdfDom = this.$refs.pdfBox
        html2canvas(pdfDom, { allowTaint: true, scale: 1 }).then(canvas => {
          // a4纸的正常尺寸是宽592.28，高是841.89，这里针对我自己的项目将宽高调换了
          const pageWidth = 592.28
          const pageHeight = 841.89
          // 设置内容的宽高
          const contentWidth = canvas.width
          const contentHeight = canvas.height
          // 默认的偏移量
          let position = 0
          // 设置生成图片的宽高
          const imgCanvasWidth = pageWidth - 40
          const imgCanvasHeight = (592.28 / contentWidth) * contentHeight
          let imageHeight = imgCanvasHeight
          // 生成canvas截图，1表示生成的截图质量（0-1）
          let pageData = canvas.toDataURL('image/jpeg', 1)
          // new JsPDF接收三个参数，landscape表示横向，（默认不填是纵向），打印单位和纸张尺寸
          let PDF = new jsPDF('', 'pt', 'a4')

          // 当内容不超过a4纸一页的情况下
          if (imageHeight < pageHeight) {
            PDF.addImage(
              pageData,
              'JPEG',
              21,
              20,
              imgCanvasWidth,
              imgCanvasHeight,
              'FAST'
            )
          } else {
            // 当内容超过a4纸一页的情况下，需要增加一页
            while (imageHeight > 0) {
              PDF.addImage(
                pageData,
                'JPEG',
                20,
                position,
                imgCanvasWidth,
                imgCanvasHeight,
                'FAST'
              )
              imageHeight -= pageHeight
              position -= pageHeight
              // 避免添加空白页
              if (imageHeight > 0) {
                PDF.addPage()
              }
            }
          }
          // 调用save方法生成pdf文件
          PDF.save(this.projectInfo.projectName + '.pdf')
        })
      })
    }
  }
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';



.table-box {
  width: 100%;
  max-height: 820PX;
  margin-top: 10PX;
  overflow: auto;
  padding: 15PX;
  background: #FFF;

  table {
    table-layout: fixed;
    width: 100%;
    color: #333;

    td,
    th {
      text-align: center;
      padding: 15PX;
      font-size: 18PX !important;
      border: 1PX solid #333;
      font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
    }

    :last-child {

      td,
      th {
        border-bottom: 0;
      }
    }

    tr:nth-child(2n + 1) {

      td,
      th {
        border-top: 0;
        border-bottom: 0;
      }
    }

    .text-box {
      text-align: left;
      letter-spacing: 3PX;
      // text-indent: 38PX;
    }
  }

  .table-tile {
    letter-spacing: 2PX;
    padding: 25PX;

    P {
      font-size: 24PX;
      padding: 0;
      margin: 0;
      padding-bottom: 15PX;
    }

    border: none;
  }

  .table-ceven {
    :nth-child(2n - 1) {
      border-left: 0;
      border-right: 0;
    }

    :last-child {
      border-right: 0;
    }
  }

  .table-c-even {
    :nth-child(2n) {
      border-left: 0;
      border-right: 0;
    }

    &:last-child {
      td {
        border-bottom: 0;
      }
    }
  }
}

.export-project {
  position: absolute;
  right: 0PX;
  bottom: 0PX;
}
</style>
